@@ -38,7 +38,8 @@ AppGroup = "Application"
 CocaineGroup = "Cocaine"
 ActionGroup = "Actions"
 
-POSSIBLE_ACTIONS = ('upload', 'deploy', 'start', 'stop', 'listing', 'undeploy', 'info')
+POSSIBLE_ACTIONS = ('upload', 'deploy', 'start', 'stop',
+                    'listing', 'undeploy', 'info', 'remove')
 API_VERSION = 1.2
 
 
@@ -111,7 +112,7 @@ define('port', group=CocaineGroup,
 
 # ActionGroup
 define('action', group=ActionGroup,
-       help='action name (upload|deploy|start|stop)',
+       help='action name (%s)' % '|'.join(POSSIBLE_ACTIONS),
        type=str, default=None)
 
 
@@ -217,6 +218,22 @@ def undeploy():
         exit(1)
 
 
+@Dispatcher.attach("remove")
+def remove():
+    log.info("Application %s would be undeployed with profile.",
+             options.appname)
+    task = {"appname": options.appname,
+            "version": options.version}
+
+    try:
+        s = Service("flow@main", host=options.host, port=options.port)
+        printer = Printer()
+        map(printer.log, s.enqueue("remove", gen_task(task)))
+    except Exception as err:
+        log.error(err.msg)
+        exit(1)
+
+
 @Dispatcher.attach("listing")
 def listing():
     log.info("Fetching a list of your applications according to wildcard %s",
@@ -228,6 +245,9 @@ def listing():
             task["wildcard"] = options.wildcard
         apps = s.enqueue("list",
                          gen_task(task)).get()
+        if len(apps) == 0:
+            print('There are no applications your username')
+            return
         # ToDo: Make it pretty
         for app, status in apps.iteritems():
             user, appname = app.split('_', 1)
